A.C.I.D (Accurate Continuum fItting and Deconvolution) — ACID_code documentation

# A.C.I.D (Accurate Continuum fItting and Deconvolution)

ACID is a technique that builds on traditional Least-Squares Deconvolution (LSD) by simultaneously fitting the stellar continuum and stellar line profile and performing LSD in effective optical depth.

In a basic sense, ACID simulatenously fits the stellar continuum and profile using a combination of LSD and MCMC techniques (MCMC implementation through emcee). The spectra are then continuum corrected using this continuum fit. LSD is then run on the continuum corrected spectra to return high-resolution line profiles for each spectrum.

For a full outline of ACID’s algorithm and implementation, see our paper or view the package on GitHub.

# User Guide

- Installation
  - Installing the package
  - Installing from the source
  - Testing the installation
- Using ACID
  - Quickstart
  - Multiple frames
  - Multiple wavelength ranges
  - HARPS data
- ACID Functions
  - `ACID()`
  - `ACID_HARPS()`
  - `calc_deltav()`

# License and Attribution

Copyright 2022, Lucy Dolan.

ACID is free software made available under the MIT License.

If you make use of ACID in your work please cite our paper (L.Dolan et al, in prep).